# -*- coding: utf-8 -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2015 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU Affero General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option)
#  any later version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
#  more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Helper for Multi-Database SMS Engine Config

.. note::
   This entire module exists only for the sake of the :func:`init()` function,
   since that is (currently) required by edbob to "auto-configure" an app.
"""

from __future__ import unicode_literals

from locsms.db import Session

from rattail.db.util import get_engines


def init(config):
    """
    Load a dictionary of all SMS database engines found in the config object,
    and store the dictionary directly on the config object.  Also configure
    the default Session factory with the default engine.
    """
    engines = get_engines(config, section='rattail_locsms')
    Session.configure(bind=engines['default'])
    config.locsms_engines = engines
